import { API as ParentAPI } from '../../../bridge';
import type { DownloadInvoiceRequest, GetConsumptionRequest, GetConsumptionResponse, ListDiscountsRequest, ListDiscountsResponse, ListInvoicesRequest, ListInvoicesResponse } from './types.gen';
/**
 * Billing API.
 *
 * This API allows you to manage and query your Scaleway billing and
 * consumption.
 */
export declare class API extends ParentAPI {
    /**
     * Get current month's consumption. The consumption reflects the amount of
     * money you have spent for the products you have used. The consumption value
     * is monetary and is not computed in real time.
     *
     * @param request - The request {@link GetConsumptionRequest}
     * @returns A Promise of GetConsumptionResponse
     */
    getConsumption: (request?: Readonly<GetConsumptionRequest>) => Promise<GetConsumptionResponse>;
    protected pageOfListInvoices: (request?: Readonly<ListInvoicesRequest>) => Promise<ListInvoicesResponse>;
    /**
     * List invoices. List all your invoices, filtering by `start_date` and
     * `invoice_type`. Each invoice has its own ID.
     *
     * @param request - The request {@link ListInvoicesRequest}
     * @returns A Promise of ListInvoicesResponse
     */
    listInvoices: (request?: Readonly<ListInvoicesRequest>) => Promise<ListInvoicesResponse> & {
        all: () => Promise<import("./types.gen").Invoice[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").Invoice[], void, void>;
    };
    /**
     * Download an invoice. Download a specific invoice, specified by its ID.
     *
     * @param request - The request {@link DownloadInvoiceRequest}
     * @returns A Promise of Blob
     */
    downloadInvoice: (request: Readonly<DownloadInvoiceRequest>) => Promise<Blob>;
    protected pageOfListDiscounts: (request?: Readonly<ListDiscountsRequest>) => Promise<ListDiscountsResponse>;
    /**
     * List all user's discounts. List all discounts for an organization and
     * usable categories/products/offers/references/regions/zones where the
     * discount can be applied.
     *
     * @param request - The request {@link ListDiscountsRequest}
     * @returns A Promise of ListDiscountsResponse
     */
    listDiscounts: (request?: Readonly<ListDiscountsRequest>) => Promise<ListDiscountsResponse> & {
        all: () => Promise<import("./types.gen").Discount[]>;
        [Symbol.asyncIterator]: () => AsyncGenerator<import("./types.gen").Discount[], void, void>;
    };
}
