"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const randomName = require("@scaleway/random-name");
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const unmarshalJWT = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'JWT' failed as data isn't a dictionary.`
    );
  }
  return {
    audienceId: data.audience_id,
    createdAt: marshalling.unmarshalDate(data.created_at),
    expiresAt: marshalling.unmarshalDate(data.expires_at),
    ip: data.ip,
    issuerId: data.issuer_id,
    jti: data.jti,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    userAgent: data.user_agent
  };
};
const unmarshalAPIKey = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'APIKey' failed as data isn't a dictionary.`
    );
  }
  return {
    accessKey: data.access_key,
    applicationId: data.application_id,
    createdAt: marshalling.unmarshalDate(data.created_at),
    creationIp: data.creation_ip,
    defaultProjectId: data.default_project_id,
    description: data.description,
    editable: data.editable,
    expiresAt: marshalling.unmarshalDate(data.expires_at),
    secretKey: data.secret_key,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    userId: data.user_id
  };
};
const unmarshalApplication = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Application' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    description: data.description,
    editable: data.editable,
    id: data.id,
    name: data.name,
    nbApiKeys: data.nb_api_keys,
    organizationId: data.organization_id,
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalGroup = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Group' failed as data isn't a dictionary.`
    );
  }
  return {
    applicationIds: data.application_ids,
    createdAt: marshalling.unmarshalDate(data.created_at),
    description: data.description,
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    userIds: data.user_ids
  };
};
const unmarshalLog = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Log' failed as data isn't a dictionary.`
    );
  }
  return {
    action: data.action,
    bearerId: data.bearer_id,
    createdAt: marshalling.unmarshalDate(data.created_at),
    id: data.id,
    ip: data.ip,
    organizationId: data.organization_id,
    resourceId: data.resource_id,
    resourceType: data.resource_type,
    userAgent: data.user_agent
  };
};
const unmarshalPolicy = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Policy' failed as data isn't a dictionary.`
    );
  }
  return {
    applicationId: data.application_id,
    createdAt: marshalling.unmarshalDate(data.created_at),
    description: data.description,
    editable: data.editable,
    groupId: data.group_id,
    id: data.id,
    name: data.name,
    nbPermissionSets: data.nb_permission_sets,
    nbRules: data.nb_rules,
    nbScopes: data.nb_scopes,
    noPrincipal: data.no_principal,
    organizationId: data.organization_id,
    tags: data.tags,
    updatedAt: marshalling.unmarshalDate(data.updated_at),
    userId: data.user_id
  };
};
const unmarshalQuotum = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Quotum' failed as data isn't a dictionary.`
    );
  }
  return {
    description: data.description,
    limit: data.limit,
    name: data.name,
    prettyName: data.pretty_name,
    unit: data.unit,
    unlimited: data.unlimited
  };
};
const unmarshalSSHKey = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'SSHKey' failed as data isn't a dictionary.`
    );
  }
  return {
    createdAt: marshalling.unmarshalDate(data.created_at),
    disabled: data.disabled,
    fingerprint: data.fingerprint,
    id: data.id,
    name: data.name,
    organizationId: data.organization_id,
    projectId: data.project_id,
    publicKey: data.public_key,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalUser = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'User' failed as data isn't a dictionary.`
    );
  }
  return {
    accountRootUserId: data.account_root_user_id,
    createdAt: marshalling.unmarshalDate(data.created_at),
    deletable: data.deletable,
    email: data.email,
    id: data.id,
    lastLoginAt: marshalling.unmarshalDate(data.last_login_at),
    mfa: data.mfa,
    organizationId: data.organization_id,
    status: data.status,
    tags: data.tags,
    twoFactorEnabled: data.two_factor_enabled,
    type: data.type,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalEncodedJWT = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'EncodedJWT' failed as data isn't a dictionary.`
    );
  }
  return {
    jwt: data.jwt ? unmarshalJWT(data.jwt) : void 0,
    renewToken: data.renew_token,
    token: data.token
  };
};
const unmarshalListAPIKeysResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListAPIKeysResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    apiKeys: marshalling.unmarshalArrayOfObject(data.api_keys, unmarshalAPIKey),
    totalCount: data.total_count
  };
};
const unmarshalListApplicationsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListApplicationsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    applications: marshalling.unmarshalArrayOfObject(
      data.applications,
      unmarshalApplication
    ),
    totalCount: data.total_count
  };
};
const unmarshalListGroupsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListGroupsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    groups: marshalling.unmarshalArrayOfObject(data.groups, unmarshalGroup),
    totalCount: data.total_count
  };
};
const unmarshalListJWTsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListJWTsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    jwts: marshalling.unmarshalArrayOfObject(data.jwts, unmarshalJWT),
    totalCount: data.total_count
  };
};
const unmarshalListLogsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListLogsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    logs: marshalling.unmarshalArrayOfObject(data.logs, unmarshalLog),
    totalCount: data.total_count
  };
};
const unmarshalPermissionSet = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'PermissionSet' failed as data isn't a dictionary.`
    );
  }
  return {
    categories: data.categories,
    description: data.description,
    id: data.id,
    name: data.name,
    scopeType: data.scope_type
  };
};
const unmarshalListPermissionSetsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPermissionSetsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    permissionSets: marshalling.unmarshalArrayOfObject(
      data.permission_sets,
      unmarshalPermissionSet
    ),
    totalCount: data.total_count
  };
};
const unmarshalListPoliciesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListPoliciesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    policies: marshalling.unmarshalArrayOfObject(data.policies, unmarshalPolicy),
    totalCount: data.total_count
  };
};
const unmarshalListQuotaResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListQuotaResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    quota: marshalling.unmarshalArrayOfObject(data.quota, unmarshalQuotum),
    totalCount: data.total_count
  };
};
const unmarshalRule = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Rule' failed as data isn't a dictionary.`
    );
  }
  return {
    accountRootUserId: data.account_root_user_id,
    condition: data.condition,
    id: data.id,
    organizationId: data.organization_id,
    permissionSetNames: data.permission_set_names,
    permissionSetsScopeType: data.permission_sets_scope_type,
    projectIds: data.project_ids
  };
};
const unmarshalListRulesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListRulesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    rules: marshalling.unmarshalArrayOfObject(data.rules, unmarshalRule),
    totalCount: data.total_count
  };
};
const unmarshalListSSHKeysResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListSSHKeysResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    sshKeys: marshalling.unmarshalArrayOfObject(data.ssh_keys, unmarshalSSHKey),
    totalCount: data.total_count
  };
};
const unmarshalListUsersResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListUsersResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    totalCount: data.total_count,
    users: marshalling.unmarshalArrayOfObject(data.users, unmarshalUser)
  };
};
const unmarshalSetRulesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'SetRulesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    rules: marshalling.unmarshalArrayOfObject(data.rules, unmarshalRule)
  };
};
const marshalAddGroupMemberRequest = (request, defaults) => ({
  ...marshalling.resolveOneOf([
    { param: "user_id", value: request.userId },
    { param: "application_id", value: request.applicationId }
  ])
});
const marshalAddGroupMembersRequest = (request, defaults) => ({
  application_ids: request.applicationIds,
  user_ids: request.userIds
});
const marshalCreateAPIKeyRequest = (request, defaults) => ({
  default_project_id: request.defaultProjectId,
  description: request.description,
  expires_at: request.expiresAt,
  ...marshalling.resolveOneOf([
    { param: "application_id", value: request.applicationId },
    { param: "user_id", value: request.userId }
  ])
});
const marshalCreateApplicationRequest = (request, defaults) => ({
  description: request.description,
  name: request.name || randomName("app"),
  organization_id: request.organizationId ?? defaults.defaultOrganizationId,
  tags: request.tags
});
const marshalCreateGroupRequest = (request, defaults) => ({
  description: request.description,
  name: request.name || randomName("grp"),
  organization_id: request.organizationId ?? defaults.defaultOrganizationId,
  tags: request.tags
});
const marshalCreateJWTRequest = (request, defaults) => ({
  referrer: request.referrer,
  user_id: request.userId
});
const marshalRuleSpecs = (request, defaults) => ({
  condition: request.condition,
  permission_set_names: request.permissionSetNames,
  ...marshalling.resolveOneOf([
    { param: "project_ids", value: request.projectIds },
    { param: "organization_id", value: request.organizationId }
  ])
});
const marshalCreatePolicyRequest = (request, defaults) => ({
  description: request.description,
  name: request.name || randomName("pol"),
  organization_id: request.organizationId ?? defaults.defaultOrganizationId,
  rules: request.rules !== void 0 ? request.rules.map((elt) => marshalRuleSpecs(elt)) : void 0,
  tags: request.tags,
  ...marshalling.resolveOneOf([
    { param: "user_id", value: request.userId },
    { param: "group_id", value: request.groupId },
    { param: "application_id", value: request.applicationId },
    { param: "no_principal", value: request.noPrincipal }
  ])
});
const marshalCreateSSHKeyRequest = (request, defaults) => ({
  name: request.name || randomName("key"),
  project_id: request.projectId ?? defaults.defaultProjectId,
  public_key: request.publicKey
});
const marshalCreateUserRequest = (request, defaults) => ({
  email: request.email,
  organization_id: request.organizationId ?? defaults.defaultOrganizationId,
  tags: request.tags
});
const marshalRemoveGroupMemberRequest = (request, defaults) => ({
  ...marshalling.resolveOneOf([
    { param: "user_id", value: request.userId },
    { param: "application_id", value: request.applicationId }
  ])
});
const marshalSetGroupMembersRequest = (request, defaults) => ({
  application_ids: request.applicationIds,
  user_ids: request.userIds
});
const marshalSetRulesRequest = (request, defaults) => ({
  policy_id: request.policyId,
  rules: request.rules.map((elt) => marshalRuleSpecs(elt))
});
const marshalUpdateAPIKeyRequest = (request, defaults) => ({
  default_project_id: request.defaultProjectId,
  description: request.description
});
const marshalUpdateApplicationRequest = (request, defaults) => ({
  description: request.description,
  name: request.name,
  tags: request.tags
});
const marshalUpdateGroupRequest = (request, defaults) => ({
  description: request.description,
  name: request.name,
  tags: request.tags
});
const marshalUpdatePolicyRequest = (request, defaults) => ({
  description: request.description,
  name: request.name,
  tags: request.tags,
  ...marshalling.resolveOneOf([
    { param: "user_id", value: request.userId },
    { param: "group_id", value: request.groupId },
    { param: "application_id", value: request.applicationId },
    { param: "no_principal", value: request.noPrincipal }
  ])
});
const marshalUpdateSSHKeyRequest = (request, defaults) => ({
  disabled: request.disabled,
  name: request.name
});
const marshalUpdateUserRequest = (request, defaults) => ({
  tags: request.tags
});
exports.marshalAddGroupMemberRequest = marshalAddGroupMemberRequest;
exports.marshalAddGroupMembersRequest = marshalAddGroupMembersRequest;
exports.marshalCreateAPIKeyRequest = marshalCreateAPIKeyRequest;
exports.marshalCreateApplicationRequest = marshalCreateApplicationRequest;
exports.marshalCreateGroupRequest = marshalCreateGroupRequest;
exports.marshalCreateJWTRequest = marshalCreateJWTRequest;
exports.marshalCreatePolicyRequest = marshalCreatePolicyRequest;
exports.marshalCreateSSHKeyRequest = marshalCreateSSHKeyRequest;
exports.marshalCreateUserRequest = marshalCreateUserRequest;
exports.marshalRemoveGroupMemberRequest = marshalRemoveGroupMemberRequest;
exports.marshalSetGroupMembersRequest = marshalSetGroupMembersRequest;
exports.marshalSetRulesRequest = marshalSetRulesRequest;
exports.marshalUpdateAPIKeyRequest = marshalUpdateAPIKeyRequest;
exports.marshalUpdateApplicationRequest = marshalUpdateApplicationRequest;
exports.marshalUpdateGroupRequest = marshalUpdateGroupRequest;
exports.marshalUpdatePolicyRequest = marshalUpdatePolicyRequest;
exports.marshalUpdateSSHKeyRequest = marshalUpdateSSHKeyRequest;
exports.marshalUpdateUserRequest = marshalUpdateUserRequest;
exports.unmarshalAPIKey = unmarshalAPIKey;
exports.unmarshalApplication = unmarshalApplication;
exports.unmarshalEncodedJWT = unmarshalEncodedJWT;
exports.unmarshalGroup = unmarshalGroup;
exports.unmarshalJWT = unmarshalJWT;
exports.unmarshalListAPIKeysResponse = unmarshalListAPIKeysResponse;
exports.unmarshalListApplicationsResponse = unmarshalListApplicationsResponse;
exports.unmarshalListGroupsResponse = unmarshalListGroupsResponse;
exports.unmarshalListJWTsResponse = unmarshalListJWTsResponse;
exports.unmarshalListLogsResponse = unmarshalListLogsResponse;
exports.unmarshalListPermissionSetsResponse = unmarshalListPermissionSetsResponse;
exports.unmarshalListPoliciesResponse = unmarshalListPoliciesResponse;
exports.unmarshalListQuotaResponse = unmarshalListQuotaResponse;
exports.unmarshalListRulesResponse = unmarshalListRulesResponse;
exports.unmarshalListSSHKeysResponse = unmarshalListSSHKeysResponse;
exports.unmarshalListUsersResponse = unmarshalListUsersResponse;
exports.unmarshalLog = unmarshalLog;
exports.unmarshalPolicy = unmarshalPolicy;
exports.unmarshalQuotum = unmarshalQuotum;
exports.unmarshalSSHKey = unmarshalSSHKey;
exports.unmarshalSetRulesResponse = unmarshalSetRulesResponse;
exports.unmarshalUser = unmarshalUser;
