"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const randomName = require("@scaleway/random-name");
const json = require("../../../helpers/json.cjs");
const marshalling = require("../../../helpers/marshalling.cjs");
require("../../../vendor/base64/index.cjs");
const unmarshalCronSchedule = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'CronSchedule' failed as data isn't a dictionary.`
    );
  }
  return {
    schedule: data.schedule,
    timezone: data.timezone
  };
};
const unmarshalJobDefinition = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'JobDefinition' failed as data isn't a dictionary.`
    );
  }
  return {
    command: data.command,
    cpuLimit: data.cpu_limit,
    createdAt: marshalling.unmarshalDate(data.created_at),
    cronSchedule: data.cron_schedule ? unmarshalCronSchedule(data.cron_schedule) : void 0,
    description: data.description,
    environmentVariables: data.environment_variables,
    id: data.id,
    imageUri: data.image_uri,
    jobTimeout: data.job_timeout,
    localStorageCapacity: data.local_storage_capacity,
    memoryLimit: data.memory_limit,
    name: data.name,
    projectId: data.project_id,
    region: data.region,
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalJobRun = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'JobRun' failed as data isn't a dictionary.`
    );
  }
  return {
    command: data.command,
    cpuLimit: data.cpu_limit,
    createdAt: marshalling.unmarshalDate(data.created_at),
    environmentVariables: data.environment_variables,
    errorMessage: data.error_message,
    exitCode: data.exit_code,
    id: data.id,
    jobDefinitionId: data.job_definition_id,
    localStorageCapacity: data.local_storage_capacity,
    memoryLimit: data.memory_limit,
    region: data.region,
    runDuration: data.run_duration,
    startedAt: marshalling.unmarshalDate(data.started_at),
    state: data.state,
    terminatedAt: marshalling.unmarshalDate(data.terminated_at),
    updatedAt: marshalling.unmarshalDate(data.updated_at)
  };
};
const unmarshalListJobDefinitionsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListJobDefinitionsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    jobDefinitions: marshalling.unmarshalArrayOfObject(
      data.job_definitions,
      unmarshalJobDefinition
    ),
    totalCount: data.total_count
  };
};
const unmarshalListJobRunsResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListJobRunsResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    jobRuns: marshalling.unmarshalArrayOfObject(data.job_runs, unmarshalJobRun),
    totalCount: data.total_count
  };
};
const unmarshalResource = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'Resource' failed as data isn't a dictionary.`
    );
  }
  return {
    cpuLimit: data.cpu_limit,
    memoryLimit: data.memory_limit
  };
};
const unmarshalListJobsResourcesResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'ListJobsResourcesResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    resources: marshalling.unmarshalArrayOfObject(data.resources, unmarshalResource)
  };
};
const unmarshalStartJobDefinitionResponse = (data) => {
  if (!json.isJSONObject(data)) {
    throw new TypeError(
      `Unmarshalling the type 'StartJobDefinitionResponse' failed as data isn't a dictionary.`
    );
  }
  return {
    jobRuns: marshalling.unmarshalArrayOfObject(data.job_runs, unmarshalJobRun)
  };
};
const marshalCreateJobDefinitionRequestCronScheduleConfig = (request, defaults) => ({
  schedule: request.schedule,
  timezone: request.timezone
});
const marshalCreateJobDefinitionRequest = (request, defaults) => ({
  command: request.command,
  cpu_limit: request.cpuLimit,
  cron_schedule: request.cronSchedule !== void 0 ? marshalCreateJobDefinitionRequestCronScheduleConfig(
    request.cronSchedule
  ) : void 0,
  description: request.description,
  environment_variables: request.environmentVariables !== void 0 ? request.environmentVariables : void 0,
  image_uri: request.imageUri,
  job_timeout: request.jobTimeout,
  local_storage_capacity: request.localStorageCapacity,
  memory_limit: request.memoryLimit,
  name: request.name || randomName("job"),
  project_id: request.projectId ?? defaults.defaultProjectId
});
const marshalStartJobDefinitionRequest = (request, defaults) => ({
  command: request.command,
  environment_variables: request.environmentVariables,
  replicas: request.replicas
});
const marshalUpdateJobDefinitionRequestCronScheduleConfig = (request, defaults) => ({
  schedule: request.schedule,
  timezone: request.timezone
});
const marshalUpdateJobDefinitionRequest = (request, defaults) => ({
  command: request.command,
  cpu_limit: request.cpuLimit,
  cron_schedule: request.cronSchedule !== void 0 ? marshalUpdateJobDefinitionRequestCronScheduleConfig(
    request.cronSchedule
  ) : void 0,
  description: request.description,
  environment_variables: request.environmentVariables,
  image_uri: request.imageUri,
  job_timeout: request.jobTimeout,
  local_storage_capacity: request.localStorageCapacity,
  memory_limit: request.memoryLimit,
  name: request.name
});
exports.marshalCreateJobDefinitionRequest = marshalCreateJobDefinitionRequest;
exports.marshalStartJobDefinitionRequest = marshalStartJobDefinitionRequest;
exports.marshalUpdateJobDefinitionRequest = marshalUpdateJobDefinitionRequest;
exports.unmarshalJobDefinition = unmarshalJobDefinition;
exports.unmarshalJobRun = unmarshalJobRun;
exports.unmarshalListJobDefinitionsResponse = unmarshalListJobDefinitionsResponse;
exports.unmarshalListJobRunsResponse = unmarshalListJobRunsResponse;
exports.unmarshalListJobsResourcesResponse = unmarshalListJobsResourcesResponse;
exports.unmarshalStartJobDefinitionResponse = unmarshalStartJobDefinitionResponse;
